@@ -6,6 +6,11 @@ import json
 import os
 import sys
 from os.path import join as pjoin, dirname, isfile, expanduser
+try:
+    from shlex import quote
+except ImportError:
+    from pipes import quote
+
 
 # This is the final form the kernel start command will take
 # after running kernda. It's at the module-level for ease of reference only.
@@ -55,9 +60,11 @@ def add_activation(args):
         return 1
 
     env_dir = dirname(bin_dir)
-    start_cmd = ' '.join(spec['argv'])
-    full_cmd = FULL_CMD_TMPL.format(env_dir=env_dir, start_cmd=start_cmd,
-                                    start_args=args.start_args)
+    start_cmd = ' '.join(quote(x) for x in spec['argv'])
+    full_cmd = FULL_CMD_TMPL.format(
+        env_dir=env_dir,
+        start_cmd=start_cmd,
+        start_args=args.start_args)
     spec['argv'] = ['bash', '-c', full_cmd]
 
     if args.display_name:
